import requests

from ergondata_executions.v1.auth.controller import AuthController
from ergondata_executions.v1.queue_event_subscription.interfaces import *
from ergondata_executions.v1.decorators import *

class QueueEventSubscriptionController:

    CREATE_QUEUE_EVENT_SUBSCRIPTION_URL = "queues/{0}/events/subscriptions"
    GET_QUEUE_EVENT_SUBSCRIPTIONS_URL = "queues/{0}/events/subscriptions"
    DELETE_QUEUE_EVENT_SUBSCRIPTION_URL = "queues/{0}/events/subscriptions/{1}"
    UPDATE_QUEUE_EVENT_SUBSCRIPTION_URL = "queues/{0}/events/subscriptions/{1}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client

    @api_request(log_message="Creating queue_event_subscription {event_id}", out_schema=CreateQueueEventSubscriptionResponsePayload)
    def create_queue_event_subscription(
        self,
        queue_id: StrictStr,
        event_id: StrictStr,
        payload: Any = None,
        whatsapp_integration: StrictBool = False,
        email_integration: StrictBool = False,
        webhook_integration: StrictBool = False,
        whatsapp_recipients: Optional[Union[List[WhatsappRecipient], None]] = None,
        email_recipients: Optional[Union[List[StrictStr], None]] = None,
        webhook_url: Optional[Union[StrictStr, None]] = None,
        queue_exception_id: Optional[StrictStr] = None
    ) -> CreateQueueEventSubscriptionResponsePayload:
        res: Any = requests.post(
            url=f"{self.api_client.ROOT_URL}{self.CREATE_QUEUE_EVENT_SUBSCRIPTION_URL.format(queue_id)}",
            json=CreateQueueEventSubscriptionRequestPayload(
                event_id=event_id,
                whatsapp_integration=whatsapp_integration,
                email_integration=email_integration,
                webhook_integration=webhook_integration,
                payload=payload,
                whatsapp_recipients=whatsapp_recipients,
                email_recipients=email_recipients,
                webhook_url=webhook_url,
                queue_exception_id=queue_exception_id
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Deleting queue_event_subscription {queue_event_subscription_id}", out_schema=DeleteQueueEventSubscriptionResponsePayload)
    def delete_queue_event_subscription(
        self,
        queue_id: StrictStr,
        queue_event_subscription_id: StrictStr
    ) -> DeleteQueueEventSubscriptionResponsePayload:
        res: Any = requests.delete(
            url=f"{self.api_client.ROOT_URL}{self.DELETE_QUEUE_EVENT_SUBSCRIPTION_URL.format(queue_id, queue_event_subscription_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Getting queue_event_subscriptions", out_schema=GetQueueEventSubscriptionsResponsePayload)
    def get_queue_event_subscriptions(self, queue_id: StrictStr) -> GetQueueEventSubscriptionsResponsePayload:
        res: Any = requests.get(
            url=f"{self.api_client.ROOT_URL}{self.GET_QUEUE_EVENT_SUBSCRIPTIONS_URL.format(queue_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Updating queue_event_subscription {queue_event_subscription_id}", out_schema=UpdateQueueEventSubscriptionResponsePayload)
    def update_queue_event_subscription(
        self,
        queue_event_subscription_id: StrictStr,
        queue_id: StrictStr,
        payload: Any = None,
        whatsapp_integration: StrictBool = False,
        email_integration: StrictBool = False,
        webhook_integration: StrictBool = False,
        whatsapp_recipients: Optional[Union[List[WhatsappRecipient], None]] = None,
        email_recipients: Optional[Union[List[StrictStr], None]] = None,
        webhook_url: Optional[Union[StrictStr, None]] = None,
        queue_exception_id: Optional[StrictStr] = None
    ) -> UpdateQueueEventSubscriptionResponsePayload:
        res: Any = requests.put(
            url=f"{self.api_client.ROOT_URL}{self.UPDATE_QUEUE_EVENT_SUBSCRIPTION_URL.format(queue_id, queue_event_subscription_id)}",
            json=UpdateQueueEventSubscriptionRequestPayload(
                whatsapp_integration=whatsapp_integration,
                email_integration=email_integration,
                webhook_integration=webhook_integration,
                payload=payload,
                whatsapp_recipients=whatsapp_recipients,
                email_recipients=email_recipients,
                webhook_url=webhook_url,
                queue_exception_id=queue_exception_id
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res



from ergondata_executions.interfaces import *
from ergondata_executions.v1.queue.interfaces import Queue, QueueItemStatus
from ergondata_executions.v1.task_execution.interfaces import TaskExecution
from ergondata_executions.v1.task_exception.interfaces import TaskException
from ergondata_executions.v1.queue_priority.interfaces import QueuePriority
from typing import Any
from ergondata_executions.interfaces import APIPagination

class QueueItem(BaseModel):
    id: StrictStr
    external_id: Optional[StrictStr] = None
    processing_status: QueueItemStatus
    processing_status_message: Optional[StrictStr] = None
    processing_exception: Optional[TaskException] = None
    processing_exception_ids: Optional[List[StrictStr]] = None
    processing_priority: Optional[QueuePriority] = None
    payload: Any
    queue: Queue
    task_producer_execution: Optional[TaskExecution] = None
    task_consumer_execution: Optional[TaskExecution] = None
    retries_within_count: StrictInt
    retries_outside_count: StrictInt
    created_at: datetime
    started_at: datetime
    finished_at: datetime


class CreateQueueItemRequestPayload(BaseModel):
    payload: Any
    external_id: Optional[StrictStr] = None
    processing_status_id: Optional[Literal["pending", "success", "system_error", "business_exception"]] = "pending"
    processing_status_message: Optional[StrictStr] = None
    processing_exception_id: Optional[StrictStr] = None
    processing_priority_id: Optional[StrictStr] = None


class CreateQueueItemResponsePayload(APIBaseResponse):
    data: Optional[Union[QueueItem, None]] = None


class GetQueueItemQueryParams(BaseModel):
    priority_id__in: Optional[list[StrictStr]] = None
    external_id: Optional[StrictStr] = None


class GetQueueItemResponsePayload(APIBaseResponse):
    data: Optional[QueueItem] = None


class UpdateQueueItemRequestPayload(BaseModel):
    payload: Optional[Any] = None
    processing_status_id: Optional[Literal["success", "system_error", "business_exception"]] = None
    processing_status_message: Optional[StrictStr] = None
    processing_exception_id: Optional[StrictStr] = None


class UpdateQueueItemResponsePayload(CreateQueueItemResponsePayload):
    pass


class GetQueueItemsQueryParams(BaseModel):
    page: StrictInt = 1
    page_size: StrictInt = 100
    id: Optional[StrictStr] = None
    id__in: Optional[List[StrictStr]] = None
    external_id: Optional[StrictStr] = None
    external_id__in: Optional[List[StrictStr]] = None
    payload: Optional[StrictStr] = None
    payload__contains: Optional[StrictStr] = None
    payload__regex: Optional[StrictStr] = None
    task_producer_execution_id__exact: Optional[StrictStr] = None
    task_producer_execution_id__in: Optional[List[StrictStr]] = None
    task_consumer_execution_id__exact: Optional[StrictStr] = None
    task_consumer_execution_id__in: Optional[List[StrictStr]] = None
    processing_exception_id__exact: Optional[StrictStr] = None
    processing_exception_id__in: Optional[List[StrictStr]] = None
    processing_status_message__contains: Optional[StrictStr] = None
    processing_status_message__regex: Optional[StrictStr] = None
    max_retries_within_execution: Optional[StrictInt] = None
    max_retries_within_execution__lt: Optional[StrictInt] = None
    max_retries_within_execution__gt: Optional[StrictInt] = None
    max_retries_outside_execution: Optional[StrictInt] = None
    max_retries_outside_execution__gt: Optional[StrictInt] = None
    created_at__lte: Optional[datetime] = None
    created_at__lt: Optional[datetime] = None
    created_at__gt: Optional[datetime] = None
    created_at__gte: Optional[datetime] = None
    started_at__lte: Optional[datetime] = None
    started_at__lt: Optional[datetime] = None
    started_at__gt: Optional[datetime] = None
    started_at__gte: Optional[datetime] = None
    finished_at__lte: Optional[datetime] = None
    finished_at__lt: Optional[datetime] = None
    finished_at__gt: Optional[datetime] = None
    finished_at__gte: Optional[datetime] = None


class GetQueueItemsResponsePayload(APIBaseResponse):
    data: Optional[List[QueueItem]] = None
    pagination: Optional[APIPagination] = None


class GetQueueItemsReporter(BaseModel):
    queue_id: StrictStr
    data: List[QueueItem]


import logging

from pydantic import BaseModel, StrictStr, StrictInt, StrictBool
from typing import Union, Optional, Literal, List
from ergondata_executions.interfaces import APIBaseResponse
from ergondata_executions.v1.queue_item.interfaces import GetQueueItemsQueryParams

class AuthRequestPayload(BaseModel):
    username: StrictStr
    password: StrictStr
    client_id: StrictStr


class AuthSuccessResponsePayload(BaseModel):
    token: Optional[Union[StrictStr, None]]


class AuthResponsePayload(APIBaseResponse):
    token: Optional[StrictStr] = None


class Dispatcher(BaseModel):
    task_id: StrictStr
    target_queue_id: StrictStr


class ReporterSourceQueue(BaseModel):
    id: StrictStr
    query: GetQueueItemsQueryParams = None
    add_pages: Union[StrictInt, Literal["all"], None] = None


class Reporter(BaseModel):
    task_id: StrictStr
    source_queues: List[ReporterSourceQueue]


class Linear(BaseModel):
    task_id: StrictStr


class Performer(BaseModel):
    task_id: StrictStr
    source_queue_id: StrictStr


class PerformerAndDispatcher(BaseModel):
    task_id: StrictStr
    source_queue_id: StrictStr
    target_queue_id: StrictStr


class TaskExecutionConfig(BaseModel):
    dispatcher: Dispatcher = None
    performer: Performer = None
    performer_and_dispatcher: PerformerAndDispatcher = None


class APIConfig(BaseModel):
    task_exec_config: Union[Performer, Dispatcher, PerformerAndDispatcher, Linear, Reporter] = None
    api_timeout: StrictInt = 10
    enable_logs: bool = True,
    log_file_path: StrictStr = None
    log_level: Literal["info", "debug", "error", "warning"] = "debug"
    preserve_logger_handler: StrictBool = True


import requests

from ergondata_executions.v1.auth.controller import AuthController
from ergondata_executions.v1.task_exception.interfaces import *
from ergondata_executions.v1.decorators import *

class TaskExceptionController:

    CREATE_TASK_EXCEPTION_URL = "tasks/{0}/exceptions"
    GET_TASK_EXCEPTIONS_URL = "tasks/{0}/exceptions"
    DELETE_TASK_EXCEPTION_URL = "tasks/{0}/exceptions/{1}"
    UPDATE_TASK_EXCEPTION_URL = "tasks/{0}/exceptions/{1}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client

    @api_request(log_message="Creating task_exception {name}", out_schema=CreateTaskExceptionResponsePayload)
    def create_task_exception(
        self,
        task_id: StrictStr,
        name: StrictStr,
        description: StrictStr,
        task_status_id: Literal["success", "business_exception", "system_error"]
    ) -> CreateTaskExceptionResponsePayload:
        res: Any = requests.post(
            url=f"{self.api_client.ROOT_URL}{self.CREATE_TASK_EXCEPTION_URL.format(task_id)}",
            json=CreateTaskExceptionRequestPayload(
                name=name,
                description=description,
                task_status_id=task_status_id
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Deleting task_exception {task_exception_id}", out_schema=DeleteTaskExceptionResponsePayload)
    def delete_task_exception(
        self,
        task_id: StrictStr,
        task_exception_id: StrictStr
    ) -> DeleteTaskExceptionResponsePayload:
        res: Any = requests.delete(
            url=f"{self.api_client.ROOT_URL}{self.DELETE_TASK_EXCEPTION_URL.format(task_id, task_exception_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Getting task_exceptions", out_schema=GetTaskExceptionsResponsePayload)
    def get_task_exceptions(self, task_id: StrictStr) -> GetTaskExceptionsResponsePayload:
        res: Any = requests.get(
            url=f"{self.api_client.ROOT_URL}{self.GET_TASK_EXCEPTIONS_URL.format(task_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Updating task_exception {name}", out_schema=UpdateTaskExceptionResponsePayload)
    def update_task_exception(
        self,
        task_exception_id: StrictStr,
        task_id: StrictStr,
        name: StrictStr,
        description: StrictStr,
        task_status_id: Literal["success", "reset", "released", "business_exception", "system_error"]
    ) -> UpdateTaskExceptionResponsePayload:
        res: Any = requests.put(
            url=f"{self.api_client.ROOT_URL}{self.UPDATE_TASK_EXCEPTION_URL.format(task_id, task_exception_id)}",
            json=UpdateTaskExceptionRequestPayload(
                name=name,
                description=description,
                task_status_id=task_status_id
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res



from ergondata_executions.interfaces import *
from ergondata_executions.v1.task.interfaces import Task, TaskStatus
from ergondata_executions.v1.task_exception.interfaces import TaskException
from ergondata_executions.v1.worker.interfaces import Worker
from ergondata_executions.interfaces import APIPagination


class CreateTaskExecutionRequestPayload(BaseModel):
    dev_mode: Optional[StrictBool] = True
    processing_status_message: Optional[StrictStr] = None


class TaskExecution(BaseModel):
    id: StrictStr
    task: Task
    worker: Worker
    processing_status: TaskStatus
    processing_message: Optional[StrictStr] = None
    task_exception: Optional[TaskException] = None
    dev_mode: Optional[StrictBool] = True
    created_at: datetime
    finished_at: Optional[datetime] = None


class CreateTaskExecutionResponsePayload(APIBaseResponse):
    data: Optional[TaskExecution] = None
    exec_token: Optional[StrictStr] = None


class UpdateTaskExecutionRequestPayload(BaseModel):
    processing_status_id: Optional[Literal["business_exception", "system_error", "success", None]] = None
    processing_status_message: Optional[StrictStr] = None
    task_exception_id: Optional[StrictStr] = None


class UpdateTaskExecutionResponsePayload(APIBaseResponse):
    data: Optional[TaskExecution] = None


class GetTaskExecutionsQueryParams(BaseModel):
    page: StrictInt = 1
    page_size: StrictInt = 100
    id__in: Optional[List[StrictStr]] = None
    processing_status_id__exact: Optional[Literal["success", "system_error", "business_exception", "processing"]] = None
    processing_status_id__in: Optional[List[Literal["success", "system_error", "business_exception", "processing"]]] = None
    processing_exception_id__exact: Optional[StrictStr] = None
    processing_exception_id__in: Optional[List[StrictStr]] = None
    worker_id: Optional[StrictStr] = None
    worker_id__in: Optional[StrictStr] = None
    created_at_lte: Optional[datetime] = None
    created_at_lt: Optional[datetime] = None
    created_at_gt: Optional[datetime] = None
    created_at_gte: Optional[datetime] = None
    finished_at_lte: Optional[datetime] = None
    finished_at_lt: Optional[datetime] = None
    finished_at_gt: Optional[datetime] = None
    finished_at_gte: Optional[datetime] = None


class GetTaskExecutionsResponsePayload(APIBaseResponse):
    data: List[TaskExecution]
    pagination: APIPagination


import requests
from ergondata_executions.v1.auth.controller import AuthController
from ergondata_executions.v1.task.interfaces import *
from ergondata_executions.v1.decorators import *

class TaskController:

    CREATE_TASK_URL = "tasks"
    GET_TASKS_URL = "tasks"
    DELETE_TASK_URL = "tasks/{0}"
    UPDATE_TASK_URL = "tasks/{0}"

    def __init__(self, api_client: AuthController):
        self.api_client = api_client

    @api_request(log_message="Creating task {name}", out_schema=CreateTaskResponsePayload)
    def create_task(
        self,
        process_id: StrictStr,
        name: StrictStr,
        description: StrictStr,
        task_type_id: Literal["dispatcher", "performer", "performer-and-dispatcher"],
        cron_schedule_expression: StrictStr,
        timezone: StrictStr,
        cron_schedule_expression_description: StrictStr = None,
        reset_ongoing_execution: StrictBool = False,
        release_ongoing_execution: StrictBool = False,
    ) -> CreateTaskResponsePayload:
        res: Any = requests.post(
            url=f"{self.api_client.ROOT_URL}{self.CREATE_TASK_URL}",
            json=CreateTaskRequestPayload(
                name=name,
                description=description,
                process_id=process_id,
                task_type_id=task_type_id,
                cron_schedule_expression_description=cron_schedule_expression_description,
                cron_schedule_expression=cron_schedule_expression,
                reset_ongoing_execution=reset_ongoing_execution,
                release_ongoing_execution=release_ongoing_execution,
                timezone=timezone
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Deleting task {task_id}", out_schema=DeleteTaskResponsePayload)
    def delete_task(self, task_id: StrictStr) -> DeleteTaskResponsePayload:
        res: Any = requests.delete(
            url=f"{self.api_client.ROOT_URL}{self.DELETE_TASK_URL.format(task_id)}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Getting tasks", out_schema=GetTasksResponsePayload)
    def get_tasks(self) -> GetTasksResponsePayload:
        res: Any = requests.get(
            url=f"{self.api_client.ROOT_URL}{self.GET_TASKS_URL}",
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res

    @api_request(log_message="Updating task {name}", out_schema=UpdateTaskResponsePayload)
    def update_task(
        self,
        task_id: StrictStr,
        process_id: StrictStr,
        name: StrictStr,
        description: StrictStr,
        task_type_id: Literal["dispatcher", "performer", "performer-and-dispatcher"],
        cron_schedule_expression: StrictStr,
        cron_schedule_expression_description: StrictStr,
        timezone: StrictStr
    ) -> UpdateTaskResponsePayload:
        res: Any = requests.put(
            url=f"{self.api_client.ROOT_URL}{self.UPDATE_TASK_URL.format(task_id)}",
            json=UpdateTaskRequestPayload(
                name=name,
                description=description,
                process_id=process_id,
                task_type_id=task_type_id,
                cron_schedule_expression_description=cron_schedule_expression_description,
                cron_schedule_expression=cron_schedule_expression,
                timezone=timezone
            ).model_dump(),
            headers=self.api_client.auth_header,
            timeout=self.api_client.timeout
        )
        return res
